/**
 * @file
 * Site preview.
 */

(function ($, window, Drupal, once, drupalSettings) {
  $.fn.drupalAjax = (url) => {
    const ajaxSettings = {
      url,
      dialogRenderer: 'off_canvas',
      dialogType: 'dialog',
      // @todo make width configurable and pass via drupalSettings
      dialog: { width: 480 },
    };

    Drupal.ajax(ajaxSettings).execute();
  };

  $.fn.visualEditorReload = (storage, id) => {
    if (storage === 'node' && id) {
      // Reload node after save to refresh form state.
      // The content has either been modified by another user,
      // or you have already submitted modifications.
      // As a result, your changes cannot be saved.
      // Reload Drupal page to refresh form state.
      window.location.href = `/node/${id}`;
    }
  };

  Drupal.behaviors.visualEditorLoad = {
    attach(context) {
      const { openLoad, isPreview = false } =
        drupalSettings.visual_editor.node_view;
      const { selector, node } =
        drupalSettings.decoupled_preview_iframe.node_view;
      once('visual_editor', selector, context).forEach(() => {
        if (openLoad && node) {
          $.fn.drupalAjax(
            `/visual_editor/form/node/${node}/edit?preview=${isPreview}`,
          );
        }
      });
    },
  };

  Drupal.behaviors.visualEditorListener = {
    attach() {
      window.addEventListener(
        'message',
        (event) => {
          const { wrapper } = drupalSettings.visual_editor.node_view;
          const { data } = event;
          if (data.type === 'VISUAL_EDITOR_COMPONENT') {
            const { uuid } = data;
            const uuidInput = $(`input[data-visual-editor-uuid="${uuid}"]`);
            const inputId = uuidInput.attr('id');
            const divSelector = `edit-${inputId.substring(
              0,
              inputId.indexOf('-edit--'),
            )}`;
            const divId = $(`div[data-drupal-selector="${divSelector}"]`).attr(
              'id',
            );

            if (
              wrapper.type &&
              wrapper.mode &&
              wrapper.selector &&
              wrapper.position
            ) {
              if (wrapper.type === 'tab' && Number(wrapper.position) > 0) {
                const wrapperSelector = `${wrapper.selector} > .${
                  wrapper.mode
                }-${wrapper.type}s > .${wrapper.mode}-${
                  wrapper.type
                }s-list > .${wrapper.mode}-${wrapper.type}-button-${
                  Number(wrapper.position) - 1
                }`;
                $(wrapperSelector).children(0).click();
              }
            }

            // Expand paragraph
            uuidInput.trigger('mousedown');
            // Scroll to paragraph
            document.getElementById(divId).scrollIntoView({
              behavior: 'smooth',
              block: 'start',
              inline: 'end',
            });
            event.stopImmediatePropagation();
          }
        },
        false,
      );
    },
  };
})(jQuery, window, Drupal, once, drupalSettings);
